=======
History
=======

0.2.0 (2016-6-22)
-----------------

* Change the behavior of `search` method.

  The method now reflects the fulfil search API which returns a list of
  ids. The previous behavior which returned an object with `id` and
  `rec_name` (record name) is now called `find`.

0.1.1 (2016-3-3)
------------------

* Add method to create resource.
* Add examples on how to create contacts, products and sales.

0.1.0 (2016-1-22)
------------------

* First release on PyPI.
